==> resource_planner-0.0.1.gem: app/controllers/resource_planner/events_controller.rb <==
require_dependency 'resource_planner/resource_planner_controller'

module ResourcePlanner
  class EventsController < ResourcePlannerController

    # GET /events(.:format)
    def index
      redirect_to(calendar_url)
    end

    # GET /events/:id(.:format)
    def show
      @event = ::ResourcePlanner::Event.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.xml  { render :xml => @event }
        format.json { render :json => @event }
      end
    end

    # GET /events/new(.:format)
    def new
      @event = ::ResourcePlanner::Event.new

      respond_to do |format|
        format.html # new.html.erb
        format.xml  { render :xml => @event }
        format.json { render :json => @event }
      end
    end

    # GET /events/:id/edit(.:format)
    def edit
      @event = ::ResourcePlanner::Event.find(params[:id])
    end

    # POST /events(.:format)
    def create
      @event = ::ResourcePlanner::Event.new(params[:event])

      respond_to do |format|
        if @event.save
          format.html { redirect_to(admin_course_attendee_path(@course_attendee), :notice => 'Event was successfully created.') }
          format.xml  { render :xml => @event, :status => :created, :location => @event }
          format.json { render :json => @event, :status => :created, :location => @event }
        else
          format.html { render :action => "new" }
          format.xml  { render :xml => @event.errors, :status => :unprocessable_entity }
          format.json { render :json => @event.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /events/:id(.:format)
    def update
      @event = ::ResourcePlanner::Event.find(params[:id])

      respond_to do |format|
        if @event.update_attributes(params[:event])
          format.html { redirect_to(calendar_url, :notice => 'Event was successfully updated.') }
          format.xml  { head :ok }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.xml  { render :xml => @event.errors, :status => :unprocessable_entity }
          format.json { render :json => @event.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /events/:id(.:format)
    def destroy
      @event = ::ResourcePlanner::Event.find(params[:id])
      @event.destroy

      respond_to do |format|
        format.html { redirect_to(calendar_url) }
        format.xml  { head :ok }
        format.json { head :no_content }
      end
    end

  end
end

==> resource_planner-0.1.2.gem: app/controllers/resource_planner/events_controller.rb <==
require_dependency 'resource_planner/resource_planner_controller'

module ResourcePlanner
  class EventsController < ResourcePlannerController

    # GET /events(.:format)
    def index
      #redirect_to(calendar_url)
      @events = ::ResourcePlanner::Event.all

      respond_to do |format|
        format.html # index.html.erb
        format.xml  { render :xml => @events }
        format.json # index.json.jbuilder
        #format.json { render :json => @events }
      end
    end

    # GET /events/:id(.:format)
    def show
      @event = ::ResourcePlanner::Event.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.xml  { render :xml => @event }
        format.json { render :json => @event }
      end
    end

    # GET /events/new(.:format)
    def new
      @event = ::ResourcePlanner::Event.new

      respond_to do |format|
        format.html # new.html.erb
        format.xml  { render :xml => @event }
        format.json { render :json => @event }
      end
    end

    # GET /events/:id/edit(.:format)
    def edit
      @event = ::ResourcePlanner::Event.find(params[:id])
    end

    # POST /events(.:format)
    def create
      @event = ::ResourcePlanner::Event.new(params[:event])

      respond_to do |format|
        if @event.save
          format.html { redirect_to(admin_course_attendee_path(@course_attendee), :notice => 'Event was successfully created.') }
          format.xml  { render :xml => @event, :status => :created, :location => @event }
          format.json { render :json => @event, :status => :created, :location => @event }
        else
          format.html { render :action => "new" }
          format.xml  { render :xml => @event.errors, :status => :unprocessable_entity }
          format.json { render :json => @event.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /events/:id(.:format)
    def update
      @event = ::ResourcePlanner::Event.find(params[:id])

      respond_to do |format|
        if @event.update_attributes(params[:event])
          format.html { redirect_to(calendar_url, :notice => 'Event was successfully updated.') }
          format.xml  { head :ok }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.xml  { render :xml => @event.errors, :status => :unprocessable_entity }
          format.json { render :json => @event.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /events/:id(.:format)
    def destroy
      @event = ::ResourcePlanner::Event.find(params[:id])
      @event.destroy

      respond_to do |format|
        format.html { redirect_to(calendar_url) }
        format.xml  { head :ok }
        format.json { head :no_content }
      end
    end

  end
end
